baggingTest: baggingTest function

Description Usage Arguments

View source: R/bovs2.r

Description

This function allows you to make use of the training result obtained by bagginVal to test the performance of new model

Usage

1
baggingTest(res, model_list, x_test, y_test, iteration = 1000)

Arguments

res

A vector obtained by the baggingVal function, the length is equal to the number of bootstrap done by the baggingVal function

model_list

The list is same as the one used in baggingVal function to produce res

x_test

A dataframe contains the features used by the bagginTest function

y_test

A vector contains the labels used by baggingTest function

iteration

Total number of iterations needed


CHuanSite/bovs2 documentation built on Oct. 30, 2019, 5:29 a.m.