baggingVal: baggingVal function

Description Usage Arguments

View source: R/bovs2.r

Description

This function allows you to do bagging on the validation set

Usage

1
baggingVal(model_list, x_val, y_val, iteration = 1000)

Arguments

x_val

a dataframe of features to be used as validation set

y_val

a vector indiates what is the label

iteration

the total number of bootstrap to be used, the default value is 1000

model

the list of deep learning models object returned by model in keras R


CHuanSite/bovs2 documentation built on Oct. 30, 2019, 5:29 a.m.