This function allows you to do bagging on the validation set
1 | baggingVal(model_list, x_val, y_val, iteration = 1000)
|
x_val |
a dataframe of features to be used as validation set |
y_val |
a vector indiates what is the label |
iteration |
the total number of bootstrap to be used, the default value is 1000 |
model |
the list of deep learning models object returned by model in keras R |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.